==> org.opennms.features.telemetry.config.api-24.0.0-20181215.162655-50-sources.jar: org/opennms/netmgt/telemetry/config/api/PackageDefinition.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.config.api;

/**
 * Telemetry protocol package configuration.
 */
public interface PackageDefinition {

    /**
     * The filter rule is used to match which sources should belong to this package.
     *
     * If the rule is <code>null</code>, then all sources should match.
     *
     * @return the fitler rule
     */
    String getFilterRule();

    /**
     * The RRD settings are use to control the control of RRD files, when applicable.
     *
     * @return the rrd settings
     */
    RrdDefinition getRrd();
}

==> org.opennms.features.telemetry.config.api-27.1.0-sources.jar: org/opennms/netmgt/telemetry/config/api/PackageDefinition.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.config.api;

import java.util.Map;

/**
 * Telemetry protocol package configuration.
 */
public interface PackageDefinition {

    /**
     * The filter rule is used to match which sources should belong to this package.
     *
     * If the rule is <code>null</code>, then all sources should match.
     *
     * @return the filter rule
     */
    String getFilterRule();

    /**
     * The RRD settings are use to control the control of RRD files, when applicable.
     *
     * @return the rrd settings
     */
    RrdDefinition getRrd();

    /**
     * Package specific parameters.
     *
     * @return the parameter map
     */
    Map<String, String> getParameterMap();
}
